@@ -3,14 +3,15 @@ import logging
 from django.shortcuts import get_object_or_404
 from rest_framework import mixins, viewsets
 from rest_framework.decorators import action
-from rest_framework.permissions import DjangoModelPermissions, IsAuthenticated, IsAdminUser
+from rest_framework.permissions import DjangoModelPermissions, IsAuthenticated
 from rest_framework.response import Response
 from reversion import set_comment
 from reversion.views import RevisionMixin
 
 from huscy.projects import serializers, services
 from huscy.projects.models import Project
-from huscy.projects.permissions import IsProjectCoordinator, ProjectPermission, ReadOnly
+from huscy.projects.permissions import (IsProjectCoordinator, ProjectPermission, ReadOnly,
+                                        UpdatePrincipalInvestigatorPermission)
 
 logger = logging.getLogger('projects')
 
@@ -18,7 +19,7 @@ logger = logging.getLogger('projects')
 class MembershipViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyModelMixin,
                         mixins.ListModelMixin, mixins.UpdateModelMixin, viewsets.GenericViewSet):
     serializer_class = serializers.MembershipSerializer
-    permission_classes = (IsAuthenticated, IsAdminUser | IsProjectCoordinator | ReadOnly)
+    permission_classes = (IsAuthenticated, IsProjectCoordinator | ReadOnly)
 
     def initial(self, request, *args, **kwargs):
         self.project = get_object_or_404(Project, pk=self.kwargs['project_pk'])
@@ -52,8 +53,7 @@ class MembershipViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyMo
                     membership.user.get_full_name())
 
 
-class ProjectViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyModelMixin,
-                     mixins.ListModelMixin, mixins.UpdateModelMixin, viewsets.GenericViewSet):
+class ProjectViewSet(RevisionMixin, viewsets.ModelViewSet):
     permission_classes = (IsAuthenticated, ProjectPermission)
 
     def initial(self, request, *args, **kwargs):
@@ -91,7 +91,7 @@ class ProjectViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyModel
                     self.request.user.username, project.title)
 
     @action(detail=True, methods=['PUT'],
-            permission_classes=[IsAuthenticated, IsAdminUser | IsProjectCoordinator])
+            permission_classes=[UpdatePrincipalInvestigatorPermission])
     def principalinvestigator(self, request, pk):
         serializer = serializers.PrincipalInvestigatorSerializer(instance=self.project,
                                                                  data=request.data)
